@@ -11,11 +11,13 @@ from xdis.opcodes.base import (
     def_op,
     extended_format_CALL_FUNCTION,
     extended_format_MAKE_FUNCTION_older,
+    extended_format_RAISE_VARARGS_older,
     extended_format_RETURN_VALUE,
     init_opdata,
     finalize_opcodes,
     format_CALL_FUNCTION_pos_name_encoded,
     format_MAKE_FUNCTION_default_argc,
+    format_RAISE_VARARGS_older,
     format_extended_arg,
     update_pj2,
     )
@@ -40,12 +42,13 @@ opcode_arg_fmt = {
     "CALL_FUNCTION_VAR_KW": format_CALL_FUNCTION_pos_name_encoded,
     "EXTENDED_ARG": format_extended_arg,
     "MAKE_FUNCTION": format_MAKE_FUNCTION_default_argc,
-
+    "RAISE_VARARGS": format_RAISE_VARARGS_older,
 }
 
 opcode_extended_fmt = {
     "CALL_FUNCTION": extended_format_CALL_FUNCTION,
     "MAKE_FUNCTION": extended_format_MAKE_FUNCTION_older,
+    "RAISE_VARARGS": extended_format_RAISE_VARARGS_older,
     "RETURN_VALUE": extended_format_RETURN_VALUE,
 }
 finalize_opcodes(l)
